==> onos-yang-runtime-2.2.0-sources.jar: org/onosproject/yang/gen/v1/ietfl3vpnsvc/rev20160730/ietfl3vpnsvc/accessvpnpolicy/DefaultVpnAttachment.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.accessvpnpolicy;

import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.accessvpnpolicy.vpnattachment.AttachmentFlavor;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of vpnAttachment.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultVpnAttachment extends InnerModelObject implements VpnAttachment {
    protected AttachmentFlavor attachmentFlavor;

    @Override
    public AttachmentFlavor attachmentFlavor() {
        return attachmentFlavor;
    }

    @Override
    public void attachmentFlavor(AttachmentFlavor attachmentFlavor) {
        this.attachmentFlavor = attachmentFlavor;
    }

    @Override
    public int hashCode() {
        return Objects.hash(attachmentFlavor);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultVpnAttachment) {
            DefaultVpnAttachment other = (DefaultVpnAttachment) obj;
            return
                Objects.equals(attachmentFlavor, other.attachmentFlavor);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("attachmentFlavor=" + attachmentFlavor)
            .toString();
    }


    /**
     * Creates an instance of defaultVpnAttachment.
     */
    public DefaultVpnAttachment() {
    }

}

==> onos-yang-runtime-2.3.1-sources.jar: org/onosproject/yang/gen/v1/ietfl3vpnsvc/rev20160730/ietfl3vpnsvc/accessvpnpolicy/DefaultVpnAttachment.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.accessvpnpolicy;

import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.accessvpnpolicy.vpnattachment.AttachmentFlavor;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of vpnAttachment.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultVpnAttachment extends InnerModelObject implements VpnAttachment {
    protected AttachmentFlavor attachmentFlavor;

    @Override
    public AttachmentFlavor attachmentFlavor() {
        return attachmentFlavor;
    }

    @Override
    public void attachmentFlavor(AttachmentFlavor attachmentFlavor) {
        this.attachmentFlavor = attachmentFlavor;
    }

    @Override
    public int hashCode() {
        return Objects.hash(attachmentFlavor);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultVpnAttachment) {
            DefaultVpnAttachment other = (DefaultVpnAttachment) obj;
            return
                Objects.deepEquals(attachmentFlavor, other.attachmentFlavor);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("attachmentFlavor=" + attachmentFlavor)
            .toString();
    }


    /**
     * Creates an instance of defaultVpnAttachment.
     */
    public DefaultVpnAttachment() {
    }

}
